configurationtools.set_default_accidental_spelling
==================================================

.. autofunction:: abjad.tools.configurationtools.set_default_accidental_spelling.set_default_accidental_spelling
